"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CertificationManager = void 0;
const pem_1 = require("pem");
const const_1 = require("./const");
class CertificationManager {
    rootCertification;
    certificationCachedMap = new Map();
    /**
     * 创建 CA 证书
     *
     * @author yuzhanglong
     * @date 2021-08-11 00:28:42
     * @param option pem 库关于 ca 的配置
     */
    static createCertification(option) {
        return new Promise((resolve, reject) => {
            pem_1.createCertificate(option, (error, result) => {
                if (error)
                    reject(error);
                resolve(result);
            });
        });
    }
    /**
     * 基于域名创建一个 CA 证书
     *
     * @author yuzhanglong
     * @date 2021-08-11 00:43:52
     * @param domain 域名
     */
    async createCertificationByDomain(domain) {
        if (!this.rootCertification) {
            this.rootCertification = {
                key: const_1.KEY,
                cert: const_1.CERT,
            };
        }
        const certification = await CertificationManager.createCertification({
            altNames: [domain],
            commonName: domain,
            days: const_1.MAX_DAYS,
            serviceCertificate: this.rootCertification.cert,
            serviceKey: this.rootCertification.key,
        });
        const res = {
            key: certification.clientKey,
            cert: certification.certificate,
        };
        this.certificationCachedMap.set(domain, res);
        return res;
    }
}
exports.CertificationManager = CertificationManager;
//# sourceMappingURL=certification-manager.js.map