/// <reference types="node" />
/**
 * File: rule-manager.ts
 * Description: rule 的管理类
 * Created: 2021-08-12 16:26:53
 * Author: yuzhanglong
 * Email: yuzl1123@163.com
 */
import { URL } from 'url';
import type { RuleConfig } from './types';
export declare class RuleManager {
    private mapDomainToRules;
    /**
     * 添加一条规则
     *
     * @author yuzhanglong
     * @date 2021-08-12 22:20:01
     * @param domain 域名
     * @param ruleConfig 规则配置
     */
    addRule(domain: string, ...ruleConfig: RuleConfig[]): void;
    /**
     * 给定一个 domain，获取它手下的所有注册的规则
     *
     * @author yuzhanglong
     * @param domain 需要匹配的域名，注意，不要包含后面的内容
     * @date 2021-08-12 16:41:08
     */
    matchRuleConfigurations(domain: string): RuleConfig[];
    /**
     * 获取最终代理的 URL 地址
     *
     * @author yuzhanglong
     * @date 2021-10-17 22:36:49
     */
    getProxyPassUrl(urlInstance: URL): URL | null;
    clear(): void;
    /**
     * 匹配一个域名
     *
     * @author yuzhanglong
     * @date 2021-10-17 22:37:28
     */
    matchDomain(domain: string): boolean;
}
